@@ -23,10 +23,12 @@ import (
 	"encoding/json"
 	"errors"
 	"io/ioutil"
+	"os"
 	"os/exec"
 	"sort"
 	"strconv"
 	"sync"
+	"syscall"
 
 	dbus "github.com/godbus/dbus"
 	"github.com/linuxdeepin/dde-daemon/accounts/users"
@@ -229,6 +231,9 @@ func (m *Manager) initUdcpUsers() {
 	// 解析json文件 新建udcp-cache对象,获取所有加域账户ID
 	err := m.initUdcpCache()
 	if err != nil {
+		if os.IsNotExist(err) {
+			return
+		}
 		logger.Errorf("New udcp cache object failed: %v", err)
 		return
 	}
@@ -323,6 +328,17 @@ func (m *Manager) exportUserByUid(uId string) error {
 		return err
 	}
 
+	var stat = &syscall.Stat_t{}
+	if err := syscall.Stat(u.HomeDir, stat); err != nil {
+		logger.Warning(err)
+	} else if strconv.Itoa(int(stat.Uid)) != u.Uid {
+		logger.Debug("incorrect ownership")
+		err = recoverOwnership(u)
+		if err != nil {
+			logger.Warning(err)
+		}
+	}
+
 	m.usersMapMu.Lock()
 	ch := m.userAddedChanMap[u.UserName]
 	m.usersMapMu.Unlock()
