@@ -22,8 +22,8 @@ package main
 import (
 	"time"
 
-	"pkg.deepin.io/lib/dbusutil"
-	"pkg.deepin.io/lib/log"
+	"github.com/linuxdeepin/go-lib/dbusutil"
+	"github.com/linuxdeepin/go-lib/log"
 )
 
 var logger = log.NewLogger("GreeterSetter")
