@@ -1,10 +1,10 @@
 package clipboard
 
 import (
-	"github.com/linuxdeepin/go-x11-client"
+	"github.com/linuxdeepin/go-lib/log"
+	x "github.com/linuxdeepin/go-x11-client"
 	"github.com/linuxdeepin/go-x11-client/ext/xfixes"
-	"pkg.deepin.io/dde/daemon/loader"
-	"pkg.deepin.io/lib/log"
+	"github.com/linuxdeepin/dde-daemon/loader"
 )
 
 const dbusServiceName = "com.deepin.daemon.ClipboardManager"
@@ -30,7 +30,7 @@ func (*Module) GetDependencies() []string {
 	return nil
 }
 
-func (*Module) Start() error {
+func (mo *Module) Start() error {
 	logger.Debug("clipboard module start")
 
 	xConn, err := x.NewConn()
