@@ -103,20 +103,23 @@ var defaultSysActionCmdMap = map[string]string{
 	"system-monitor":         "/usr/bin/deepin-system-monitor",
 	"color-picker":           "dbus-send --print-reply --dest=com.deepin.Picker /com/deepin/Picker com.deepin.Picker.Show",
 	// screenshot actions:
-	"screenshot":            screenshotCmdPrefix + "StartScreenshot",
-	"screenshot-fullscreen": screenshotCmdPrefix + "FullscreenScreenshot",
-	"screenshot-window":     screenshotCmdPrefix + "TopWindowScreenshot",
-	"screenshot-delayed":    screenshotCmdPrefix + "DelayScreenshot int64:5",
-	"screenshot-ocr":        screenshotCmdPrefix + "OcrScreenshot",
-	"screenshot-scroll":     screenshotCmdPrefix + "ScrollScreenshot",
-	"file-manager":          "/usr/lib/deepin-daemon/default-file-manager",
-	"disable-touchpad":      "gsettings set com.deepin.dde.touchpad touchpad-enabled false",
-	"wm-switcher":           "dbus-send --type=method_call --dest=com.deepin.WMSwitcher /com/deepin/WMSwitcher com.deepin.WMSwitcher.RequestSwitchWM",
-	"turn-off-screen":       "sleep 0.5; xset dpms force off",
-	"notification-center":   "dbus-send --print-reply --dest=com.deepin.dde.osd /org/freedesktop/Notifications com.deepin.dde.Notification.Toggle",
-	"clipboard":             "dbus-send --print-reply --dest=com.deepin.dde.Clipboard /com/deepin/dde/Clipboard com.deepin.dde.Clipboard.Toggle",
-	"global-search":         "/usr/libexec/dde-daemon/keybinding/shortcut-dde-grand-search.sh",
-	"switch-next-kbd-layout":"dbus-send --print-reply --dest=com.deepin.daemon.Keybinding /com/deepin/daemon/InputDevice/Keyboard com.deepin.daemon.InputDevice.Keyboard.ToggleNextLayout",
+	"screenshot":             screenshotCmdPrefix + "StartScreenshot",
+	"screenshot-fullscreen":  screenshotCmdPrefix + "FullscreenScreenshot",
+	"screenshot-window":      screenshotCmdPrefix + "TopWindowScreenshot",
+	"screenshot-delayed":     screenshotCmdPrefix + "DelayScreenshot int64:5",
+	"screenshot-ocr":         screenshotCmdPrefix + "OcrScreenshot",
+	"screenshot-scroll":      screenshotCmdPrefix + "ScrollScreenshot",
+	"file-manager":           "/usr/lib/deepin-daemon/default-file-manager",
+	"disable-touchpad":       "gsettings set com.deepin.dde.touchpad touchpad-enabled false",
+	"wm-switcher":            "dbus-send --type=method_call --dest=com.deepin.WMSwitcher /com/deepin/WMSwitcher com.deepin.WMSwitcher.RequestSwitchWM",
+	"turn-off-screen":        "sleep 0.5; xset dpms force off",
+	"notification-center":    "dbus-send --print-reply --dest=com.deepin.dde.osd /org/freedesktop/Notifications com.deepin.dde.Notification.Toggle",
+	"clipboard":              "dbus-send --print-reply --dest=com.deepin.dde.Clipboard /com/deepin/dde/Clipboard com.deepin.dde.Clipboard.Toggle",
+	"global-search":          "/usr/libexec/dde-daemon/keybinding/shortcut-dde-grand-search.sh",
+	"switch-next-kbd-layout": "dbus-send --print-reply --dest=com.deepin.daemon.Keybinding /com/deepin/daemon/InputDevice/Keyboard com.deepin.daemon.InputDevice.Keyboard.ToggleNextLayout",
+	// cmd
+	"calculator": "/usr/bin/deepin-calculator",
+	"search":     "/usr/libexec/dde-daemon/keybinding/shortcut-dde-grand-search.sh",
 }
 
 type actionHandler struct {
