@@ -21,5 +21,25 @@
 			<source>Clear fingerprint passwords</source>
 			<translation>رمزهای عبور اثر انگشت را پاک کن</translation>
 		</message>
+		<message>
+			<location filename="com.deepin.daemon.fprintd.rename-enrolled-finger!message" line="0"/>
+			<source>Authentication is required to rename fingerprint password</source>
+			<translation type="unfinished"/>
+		</message>
+		<message>
+			<location filename="com.deepin.daemon.fprintd.rename-enrolled-finger!description" line="0"/>
+			<source>Rename fingerprint password</source>
+			<translation type="unfinished"/>
+		</message>
+		<message>
+			<location filename="com.deepin.daemon.fprintd.manager!message" line="0"/>
+			<source>Password is required to perform this action</source>
+			<translation type="unfinished"/>
+		</message>
+		<message>
+			<location filename="com.deepin.daemon.fprintd.manager!description" line="0"/>
+			<source>Manage fingerprint passwords</source>
+			<translation type="unfinished"/>
+		</message>
 	</context>
 </TS>
\ No newline at end of file
