@@ -3,11 +3,11 @@ package proxychains
 import (
 	dbus "github.com/godbus/dbus"
 	notifications "github.com/linuxdeepin/go-dbus-factory/org.freedesktop.notifications"
-	. "pkg.deepin.io/lib/gettext"
+	. "github.com/linuxdeepin/go-lib/gettext"
 )
 
 var (
-	notification            *notifications.Notifications
+	notification            notifications.Notifications
 	notifyIconProxyEnabled  = "notification-network-proxy-enabled"
 	notifyIconProxyDisabled = "notification-network-proxy-disabled"
 )
